@@ -665,6 +665,9 @@ SERVICE_VERSIONS = {
     "trp": [
         "2021-05-15"
     ],
+    "trro": [
+        "2022-03-25"
+    ],
     "trtc": [
         "2019-07-22"
     ],
